<?php

namespace App\Http\Controllers\Card;

use App\Http\Controllers\Controller;
use App\Http\Requests\Card\AddCardCodeRequest;
use App\Http\Requests\Card\AddCardQuantityRequest;
use App\Http\Requests\Card\AddCardRequest;
use App\Http\Requests\Card\CardCodeIdRequest;
use App\Http\Requests\Card\CardIdRequest;
use App\Http\Requests\Card\CardQuantityIdRequest;
use App\Http\Requests\Card\CardSearchRequest;
use App\Http\Requests\Card\UpdateCardRequest;
use App\Http\Resources\Card\ShowCardsResource;
use App\Http\Resources\Card\ShowOneCardResource;
use App\Interfaces\Repository;
use App\Models\Card;
use App\Models\CardCode;
use App\Models\CardQuantity;
use App\Models\Currency;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class CardController extends Controller
{
    public function __construct(public Repository $repository)
    {
    }

    public function Create(AddCardRequest $request)
    {
        $arr = Arr::only($request->validated(),
            ['card_sub_id', 'name_ar', 'name_en', 'description_ar', 'description_en', 'image', 'price', 'currency_id', 'quantity', 'codes']);
        $path = 'Images/Items/';
        $arr['image'] = \uploadImage($arr['image'], $path);
        $card = $this->repository->Create(Card::class, $arr);
        if (\array_key_exists('codes', $arr)) {
            $this->CreateCardCodes($card->id, $arr['codes']);
        }
        return \Success('Card Created Successfully');
    }

    private function CreateCardCodes($id, $codes)
    {
        foreach ($codes as $code) {
            CardCode::create([
                'card_id' => $id,
                'code' => $code,
            ]);
        }
    }


    public function ActiveOrNot(CardIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardId']);
        $this->repository->ActiveOrNot(Card::class, $arr['cardId']);
        return \Success('Card Changed Successfully');
    }

    public function Delete(CardIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardId']);
        $card = $this->repository->ShowById(Card::class, $arr['cardId']);
        $card->CardCodes()->delete();
        $this->repository->DeleteById(Card::class, $arr['cardId']);
        return \Success('Card Deleted Successfully');

    }

    public function AddCardCode(AddCardCodeRequest $request)
    {
        $arr = Arr::only($request->validated(), ['card_id', 'code']);
        $this->repository->Create(CardCode::class, $arr);
        $this->repository->ShowById(Card::class, $arr['card_id'])->increment('quantity');
        return \Success('Card Code Created Successfully');
    }


    public function DeleteCardCode(CardCodeIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardCodeId']);
        $this->repository->ShowById(CardCode::class, $arr['cardCodeId'])->Card->decrement('quantity');
        $this->repository->DeleteById(CardCode::class, $arr['cardCodeId']);
        return \Success('Card Code Deleted Successfully');
    }


    public function ShowById(CardIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardId']);
        $card = $this->repository->ShowById(Card::class, $arr['cardId']);
        return \SuccessData('Card Found Successfully', new ShowOneCardResource($card));

    }

    public function ShowAll(CardSearchRequest $request)
    {
        $arr = Arr::only($request->validated(), ['search', 'cardSubId', 'currency']);
        $where = [];
        $perPage = \returnPerPage();
        if (\array_key_exists('search', $arr)) {
            $language = \returnLanguage();
            $name = 'name_' . $language;
            $where = \array_merge($where, [[$name, 'like', '%' . $arr['search'] . '%']]);
        }
        if (\array_key_exists('cardSubId', $arr)) {
            $where = \array_merge($where, ['card_sub_id' => $arr['cardSubId']]);
        }
        if (\array_key_exists('currency', $arr)) {
            $currencyId = $this->repository->ShowAll(Currency::class, ['name' => $arr['currency']])->first()->id;
            $where = \array_merge($where, ['currency_id' => $currencyId]);
        }
        $cards = $this->repository->ShowAll(Card::class, $where);
        if (\request()->route()->getPrefix() == 'customer_api') {
            $cards = $cards->Active();
        }
        $cards = $cards->paginate($perPage);
        ShowCardsResource::collection($cards);
        return \Pagination($cards);
    }

    public function Update(UpdateCardRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardId', 'name_ar', 'name_en', 'description_ar', 'description_en', 'price', 'image']);
        if (\array_key_exists('image', $arr)) {
            $path = 'Images/Items/';
            $arr['image'] = \uploadImage($arr['image'], $path);
        }
        $this->repository->Update(Card::class, $arr['cardId'], $arr);
        return \Success('Card Updated Successfully');
    }
}
