<?php

namespace App\Http\Controllers\CardCategory;

use App\Http\Controllers\Controller;
use App\Http\Requests\Card\AddCardCodeRequest;
use App\Http\Requests\CardCategory\AddCardCategoryRequest;
use App\Http\Requests\CardCategory\CardCategoryIdRequest;
use App\Http\Requests\CardCategory\CardCategorySearchRequest;
use App\Http\Requests\CardCategory\UpdateCardCategoryRequest;
use App\Http\Requests\Category\AddCategoryRequest;
use App\Http\Resources\CardCategory\ShowCardCategoryResource;
use App\Http\Resources\CardCategory\ShowOneCardCategoryResource;
use App\Interfaces\Repository;
use App\Models\Card;
use App\Models\CardCategory;
use App\Models\CardCode;
use App\Models\Category;
use App\Models\Image;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class CardCategoryController extends Controller
{
    public function __construct(public Repository $repository)
    {
    }

    public function Create(AddCardCategoryRequest $request)
    {
        $arr = Arr::only($request->validated(), ['name_ar', 'name_en', 'image']);
        $path = 'Images/Categories/';
        $arr['image'] = \uploadImage($arr['image'], $path);
        $this->repository->Create(CardCategory::class, $arr);
        return \Success('Card Category Add Successfully');
    }


    public function ActiveOrNot(CardCategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardCategoryId']);
        $this->repository->ActiveOrNot(CardCategory::class, $arr['cardCategoryId']);
        return \Success('Card Category Changed Successfully');
    }

    public function Update(UpdateCardCategoryRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardCategoryId', 'name_ar', 'name_en', 'image']);
        if (\array_key_exists('image', $arr)) {
            $path = 'Images/Categories/';
            $arr['image'] = \uploadImage($arr['image'], $path);
        }
        $this->repository->Update(CardCategory::class, $arr['cardCategoryId'], $arr);
        return \Success('Card Category Update Successfully');
    }

    public function ShowAll(CardCategorySearchRequest $request)
    {
        $arr = Arr::only($request->validated(), ['search']);
        $language = \returnLanguage();
        $perPage = \returnPerPage();
        $where = [];
        if (\array_key_exists('search', $arr)) {
            $where = \array_merge($where, [['name_' . $language, 'like', '%' . $arr['search'] . '%']]);
        }
        $cardCategories = $this->repository->ShowAll(CardCategory::class, $where);
        if (\request()->route()->getPrefix() == 'customer_api') {
            $cardCategories->Active();
        }
        $cardCategories = $cardCategories->paginate($perPage);
        ShowCardCategoryResource::collection($cardCategories);
        return \Pagination($cardCategories);
    }

    public function ShowById(CardCategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardCategoryId']);
        $cardCategory = $this->repository->ShowById(CardCategory::class, $arr['cardCategoryId']);
        return \SuccessData('Category Found Successfully', new ShowOneCardCategoryResource($cardCategory));
    }

    public function Delete(CardCategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardCategoryId']);
        $category = $this->repository->ShowById(CardCategory::class, $arr['cardCategoryId']);
        CardCode::whereHas('Card.CardSubCategory',function ($q) use ($arr){
          $q->where('card_category_id', $arr['cardCategoryId']);
        })->delete();
        Card::whereHas('CardSubCategory', function ($q) use ($arr) {
            $q->where('card_category_id', $arr['cardCategoryId']);
        })->delete();
        $category->CardSubCategories()->delete();
        $category->delete();
        return \Success('Card Category Deleted Successfully');

    }


}
