<?php

namespace App\Http\Controllers\CardOrder;

use App\Http\Controllers\Controller;
use App\Http\Requests\CardOrder\AddCardOrderRequest;
use App\Http\Requests\CardOrder\CardOrderStatusRequest;
use App\Http\Requests\CardOrder\ShowCardOrdersRequest;
use App\Http\Resources\CardOrder\CardOrdersResource;
use App\Interfaces\Repository;
use App\Models\Card;
use App\Models\CardCode;
use App\Models\CardOrder;
use App\Services\ChangeCurrencyService;
use GrahamCampbell\ResultType\Success;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class CardOrderController extends Controller
{
    public function __construct(public Repository $repository, public ChangeCurrencyService $service)
    {
    }

    public function Create(AddCardOrderRequest $request)
    {
        $arr = Arr::only($request->validated(), ['card_id', 'player_id']);
        $currency = \returnCurrency();
        $language = \returnLanguage();
        $description = 'description_' . $language;
        $card = $this->repository->ShowById(Card::class, $arr['card_id']);
        $code = null;
        $arr['language'] = $language;
        if ($card->quantity) {
            $code = $this->repository->ShowAll(CardCode::class, ['card_id' => $arr['card_id']])->first();
            $arr['code_id'] = $code->id;
            $card->decrement('quantity');
        }
        $customer = \auth('Customer')->user();
        $arr['customer_id'] = $customer->id;
        $arr['currency_id'] = $this->service->ChangeCurrency($currency)->id;
        $arr['price'] = $this->service->ChangePriceByCurrency($card->price, $card->Currency->name, $currency);
        $order = $this->repository->Create(CardOrder::class, $arr);
        $price = $this->service->ChangePriceByCurrency($card->price, $card->Currency->name, 'Dinar');
          
            $customer->decrement('balance', $price);
        $order['code'] = $code ? $code->code : $code;
        $order['description'] = $card->$description;
        $code ? $code->delete() : $code;
        return \SuccessData('Order Add Successfully', $order);
    }

    public function ChangeCardOrderStatus(CardOrderStatusRequest $request)
    {
       $arr = Arr::only($request->validated(), ['cardOrderId', 'status']);
        $order = $this->repository->ShowById(CardOrder::class, $arr['cardOrderId']);
        $customer = $order->Customer;
        if ($arr['status'] == 'canceled') {
           
            $price = $this->service->ChangePriceByCurrency($order->price, $order->Currency->name, 'Dinar');
           
            $customer->increment('balance', $price);
            $notificationData = [
    'fcm_token' => $customer->fcm_token,
    'title' => 'order number ' . $arr['cardOrderId'],
    'body' => 'The Card Order Rejected',
];
        }
        else{
            $notificationData = [
    'fcm_token' => $customer->fcm_token,
    'title' => 'order number ' . $arr['cardOrderId'],
    'body' => 'The Card Order Accepted',
];
        }
        
        $this->sendNotification($notificationData);
        $this->repository->Update(CardOrder::class, $arr['cardOrderId'], $arr);
        return \Success('Order Status Changed Successfully');
    }

    public function ShowAll(ShowCardOrdersRequest $request)
    {
        $arr = Arr::only($request->validated(), ['customerId', 'status']);
        $where = [];
        $perPage = \returnPerPage();
        if (\array_key_exists('customer_id', $arr)) {
            $where = \array_merge($where, ['customer_id' => $arr['customerId']]);
        }
        if (\array_key_exists('status', $arr)) {
            $where = \array_merge($where, ['status' => $arr['status']]);
        }
        $orders = $this->repository->ShowAll(CardOrder::class, $where)->paginate($perPage);
        CardOrdersResource::collection($orders);
        return \Pagination($orders);
    }

 private function sendNotification($arr)
    {
          
            $firebaseToken[0] = $arr['fcm_token'];
       
        $SERVER_API_KEY = 'AAAAdFHao_4:APA91bG0sDJmn1rQYJfXILJLvfIVTl92OQJbO4c0sMVDtZDE7v-uJ1gJDS77KEgTKIs_LtHUSui_9eMTIXChDB93rBvx_8zU3w-S9Qq7mONDKQCbccY9u9uiHlmu_psyhsTtmKySVuBO';

        $data = [
            "registration_ids" => $firebaseToken,
            "notification" => [
                "title" => $arr['title'],
                "body" => $arr['body'],
                "content_available" => true,
                "priority" => "high",
            ]
        ];
        $dataString = json_encode($data);

        $headers = [
            'Authorization: key=' . $SERVER_API_KEY,
            'Content-Type: application/json',
        ];

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);

        $response = curl_exec($ch);

        return \Success('Notification Send Successfully');
    }

}
