<?php

namespace App\Http\Controllers\CardSubCategory;

use App\Http\Controllers\Controller;
use App\Http\Requests\CardSubCategory\AddCardSubCategoryRequest;
use App\Http\Requests\CardSubCategory\CardSubCategoryIdRequest;
use App\Http\Requests\CardSubCategory\CardSubCategorySearchRequest;
use App\Http\Requests\CardSubCategory\UpdateCardSubCategoryRequest;
use App\Http\Resources\CardSubCategory\CardSubCategoriesResource;
use App\Interfaces\Repository;
use App\Models\CardCode;
use App\Models\CardSubCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class CardSubCategoryController extends Controller
{
    public function __construct(public Repository $repository)
    {
    }

    public function Create(AddCardSubCategoryRequest $request)
    {
        $arr = Arr::only($request->validated(), ['card_category_id', 'name_ar', 'name_en', 'image', 'description_ar', 'description_en']);
        $path = 'Images/Categories/';
        $arr['image'] = \uploadImage($arr['image'], $path);
        $this->repository->Create(CardSubCategory::class, $arr);
        return \Success('Card Sub Category Added Successfully');
    }

    public function ActiveOrNot(CardSubCategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardSubId']);
        $this->repository->ActiveOrNot(CardSubCategory::class, $arr['cardSubId']);
        return \Success('Card Sub Category Changed Successfully');
    }

    public function ShowById(CardSubCategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardSubId']);
        $cardSubCategory = $this->repository->ShowById(CardSubCategory::class, $arr['cardSubId']);
        return \SuccessData('Card Sub Category Found Successfully', $cardSubCategory);
    }

    public function ShowAll(CardSubCategorySearchRequest $request)
    {
        $arr = Arr::only($request->validated(), ['search', 'cardCategoryId']);
        $where = [];
        $perPage = \returnPerPage();
        if (\array_key_exists('search', $arr)) {
            $language = \returnLanguage();
            $name = 'name_' . $language;
            $where = \array_merge($where, [[$name, 'like', '%' . $arr['search'] . '%']]);
        }
        if (\array_key_exists('cardCategoryId', $arr)) {
            $where = \array_merge($where, ['card_category_id' => $arr['cardCategoryId']]);
        }
        $cardSubCategories = $this->repository->ShowAll(CardSubCategory::class, $where)->paginate($perPage);
        CardSubCategoriesResource::collection($cardSubCategories);
        return \Pagination($cardSubCategories);
    }


    public function Update(UpdateCardSubCategoryRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardSubId', 'card_category_id', 'name_ar', 'name_en', 'description_ar', 'description_en', 'image']);
        if (\array_key_exists('image', $arr)) {
            $path = 'Images/Categories/';
            $arr['image'] = \uploadImage($arr['image'], $path);
        }
        $this->repository->Update(CardSubCategory::class, $arr['cardSubId'], $arr);
        return \Success('Card Sub Category Updated Successfully');
    }

    public function Delete(CardSubCategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['cardSubId']);
        $subCategory = $this->repository->ShowById(CardSubCategory::class, $arr['cardSubId']);
        CardCode::whereHas('Card', function ($q) use ($arr) {
            $q->where('card_sub_id', $arr['cardSubId']);
        })->delete();
        $subCategory->Cards()->delete();
        $subCategory->delete();
        return \Success('Card Sub Category Deleted Successfully');

    }
}
