<?php

namespace App\Http\Controllers\Cart;

use App\Http\Controllers\Controller;
use App\Http\Requests\Cart\AddCartRequest;
use App\Http\Requests\Cart\CartIdRequest;
use App\Http\Requests\Cart\UpdateCartRequest;
use App\Http\Requests\Category\CategoryIdRequest;
use App\Http\Resources\Cart\ShowCartsResource;
use App\Interfaces\Repository;
use App\Models\Cart;
use App\Models\CartItem;
use App\Models\Item;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class CartController extends Controller
{

    public function __construct(public Repository $repository)
    {
    }

    public function AddToCart(AddCartRequest $request)
    {
        $arr = Arr::only($request->validated(), ['item_id', 'color_id', 'quantity']);
        $customer_id = \auth('Customer')->user()->id;
        $cart_id = $this->CheckCartAndReturnCartId($customer_id);
        $arr['cart_id'] = $cart_id;
        $this->CheckIfCartContainThisItem($arr);
        return \Success('Item Add Successfully To Cart');
    }

    private function CheckCartAndReturnCartId($customer_id)
    {
        $cart = $this->repository->ShowAll(Cart::class, ['status' => 'initial',
            'customer_id' => $customer_id,
        ])->first();
        if (!$cart) {
            $cart = $this->repository->Create(Cart::class, ['customer_id' => $customer_id]);
        }

        return $cart->id;
    }

    private function CheckIfCartContainThisItem(array $arr)
    {

        $where = [
            'cart_id' => $arr['cart_id'],
            'item_id' => $arr['item_id'],
        ];
        if(\array_key_exists('color_id',$arr)){
            $where['color_id'] = $arr['color_id'];
        }
        $cartItems = $this->repository->ShowAll(CartItem::class,$where)->first();

        if(!$cartItems){
             $this->repository->Create(CartItem::class,$arr);
        }
        else{
            $cartItems->increment('quantity', $arr['quantity']);
        }

    }


    public function ShowCart(){
        $customer_id =  \auth('Customer')->user()->id;
        $where = [
            'status' => 'initial',
            'customer_id' => $customer_id,
        ];
        $cart = $this->repository->ShowAll(Cart::class,$where)->first();
        if(!$cart){
           return \SuccessData('Carts Found Successfully',[]);
        }
        $cartItems = $cart->CartItems;
        return \SuccessData('Carts Found Successfully',ShowCartsResource::collection($cartItems));
    }


    public function EditCart(UpdateCartRequest $request){
        $arr = Arr::only($request->validated(),['cartId','quantity']);
        $this->repository->Update(CartItem::class,$arr['cartId'],$arr);
        return \Success('Cart Item Edit Successfully');
    }

    public function DeleteCart(CartIdRequest $request){
        $arr = Arr::only($request->validated(),['cartId']);
        $this->repository->DeleteById(CartItem::class,$arr['cartId']);
        return \Success('Cart Deleted Successfully');

    }

    public function DeleteAllCartItems(){
        $customer_id = \auth('Customer')->user()->id;
        $where = [
            'customer_id' => $customer_id,
            'status' => 'initial',
        ];
        $cart = $this->repository->ShowAll(Cart::class,$where)->first();
        if (!$cart){
            throw new NotFoundHttpException('Dont Have Carts');
        }
        $cart->CartItems()->delete();
        return \Success('Items Deleted Successfully');
    }
}
