<?php

namespace App\Http\Controllers\Category;

use App\Http\Controllers\Controller;
use App\Http\Requests\Category\AddCategoryRequest;
use App\Http\Requests\Category\CategoryIdRequest;
use App\Http\Requests\Category\CategorySearchRequest;
use App\Http\Requests\Category\UpdateCategoryRequest;
use App\Http\Requests\Image\ImageIdRequest;
use App\Http\Resources\Category\ShowCategoriesResource;
use App\Http\Resources\Category\ShowOneCategoryResource;
use App\Interfaces\Repository;
use App\Models\Category;
use App\Models\Image;
use App\Models\ItemColor;
use App\Models\ItemOffer;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class CategoryController extends Controller
{
    public function __construct(public Repository $repository)
    {
        $this->middleware('permission:category_items_management', ['only' => ['Create', 'ActiveOrNot', 'Update']]);
    }

    public function Create(AddCategoryRequest $request)
    {
        $arr = Arr::only($request->validated(), ['name_ar', 'name_en', 'images']);
        $category = $this->repository->Create(Category::class, $arr);
        $this->CreateCategoryImages($category->id, $arr['images']);
        return \Success('Category Add Successfully');

    }

    private function CreateCategoryImages($id, array $images)
    {
        $path = 'Images/Categories/';
        foreach ($images as $image) {
            Image::create([
                'imageable_type' => Category::class,
                'imageable_id' => $id,
                'url' => \uploadImage($image, $path),
            ]);
        }
    }

    public function ActiveOrNot(CategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['categoryId']);
        $this->repository->ActiveOrNot(Category::class, $arr['categoryId']);
        return \Success('Category Changed Successfully');
    }

    public function ShowById(CategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['categoryId']);
        $category = $this->repository->ShowById(Category::class, $arr['categoryId']);
        return \SuccessData('Category Found Successfully', new ShowOneCategoryResource($category));
    }

    public function ShowAll(CategorySearchRequest $request)
    {
        $arr = Arr::only($request->validated(), ['search']);
        $language = \returnLanguage();
        $perPage = \returnPerPage();
        $where = [];
        if (\array_key_exists('search', $arr)) {
            $where = \array_merge($where, [['name_' . $language, 'like', '%' . $arr['search'] . '%']]);
        }
        $categories = $this->repository->ShowAll(Category::class, $where);
        if (\request()->route()->getPrefix() == 'customer_api') {
            $categories->Active();
        }
        $categories = $categories->paginate($perPage);
        ShowCategoriesResource::collection($categories);
        return \Pagination($categories);
    }

    public function Update(UpdateCategoryRequest $request)
    {
        $arr = Arr::only($request->validated(), ['categoryId', 'name_ar', 'name_en', 'images']);
        $this->repository->Update(Category::class, $arr['categoryId'], $arr);
        if (\array_key_exists('images', $arr)) {
            $this->repository->ShowById(Category::class, $arr['categoryId'])->Images()->delete();
            $this->CreateCategoryImages($arr['categoryId'], $arr['images']);
        }
        return \Success('Category Update Successfully');
    }

    public function Delete(CategoryIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['categoryId']);
        $category = $this->repository->ShowById(Category::class, $arr['categoryId']);
        ItemOffer::whereHas('Item', function ($q) use ($arr) {
            $q->where('category_id', $arr['categoryId']);
        })->delete();
        ItemColor::whereHas('Item', function ($q) use ($arr) {
            $q->where('category_id', $arr['categoryId']);
        })->delete();
        $category->Items()->delete();
        $category->delete();
        return \Success('Category Deleted Successfully');

    }

}
