<?php

namespace App\Http\Controllers\Communication;

use App\Http\Controllers\Controller;
use App\Http\Requests\Communication\AddAppRequest;
use App\Http\Requests\Communication\AppIdRequest;
use App\Http\Requests\Communication\CreateLinkRequest;
use App\Http\Requests\Communication\LinkIdRequest;
use App\Http\Requests\Communication\UpdateLinksRequest;
use App\Http\Requests\Communication\UpdateAppRequest;
use App\Interfaces\Repository;
use App\Models\App;
use App\Models\Link;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use phpseclib3\Common\Functions\Strings;
use Symfony\Component\VarDumper\Caster\LinkStub;

class CommunicationController extends Controller
{
    public function __construct(public Repository $repository)
    {
    }

    public function CreateApp(AddAppRequest $request)
    {
        $arr = Arr::only($request->validated(), ['name', 'icon']);
        $path = 'Images/Apps/';
        $arr['icon'] = \uploadImage($arr['icon'], $path);
        $this->repository->Create(App::class, $arr);
        return \Success('App Add Successfully');
    }

    public function DeleteApp(AppIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['appId']);
        $this->repository->DeleteById(App::class, $arr['appId']);
        $this->repository->ShowAll(Link::class, ['app_id' => $arr['appId']])->delete();
        return \Success('App Deleted Successfully');
    }

    public function ShowAllApps()
    {
        $apps = $this->repository->ShowAll(App::class, [])->get();
        return \SuccessData('Apps Found Successfully', $apps);
    }

    public function CreateLink(CreateLinkRequest $request)
    {
        $arr = Arr::only($request->validated(), ['app_id', 'url']);
        $this->repository->Create(Link::class, $arr);
        return \Success('Link Add Successfully');
    }

    public function UpdateApp(UpdateAppRequest $request)
    {
        $arr = Arr::only($request->validated(), ['appId','name','icon']);
        if (\array_key_exists('icon', $arr)) {
            $path = 'Images/Apps/';
            $arr['icon'] = \uploadImage($arr['icon'], $path);
        }
            $this->repository->Update(App::class, $arr['appId'], $arr);
       
        return \Success('App Updated Successfully');
    }

    public function UpdateLinks(UpdateLinksRequest $request)
    {
        $arr = Arr::only($request->validated(), ['linkId','url']);
       
            $this->repository->Update(Link::class, $arr['linkId'], $arr);
       
        return \Success('Link Updated Successfully');
    }

    public function DeleteLink(LinkIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['linkId']);
        $this->repository->DeleteById(Link::class, $arr['linkId']);
        return \Success('Link Deleted Successfully');
    }

    public function ShowAllLinks()
    {
        $links = $this->repository->ShowAll(Link::class, [])->with('App')->get();
        return \SuccessData('Links Found Successfully', $links);

    }
}
