<?php

namespace App\Http\Controllers\Image;

use App\Http\Controllers\Controller;
use App\Http\Requests\Image\ImageIdRequest;
use App\Interfaces\Repository;
use App\Models\Image;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\File;
use Illuminate\Validation\ValidationException;


class ImageController extends Controller
{
    public function __construct(public Repository $repository)
    {
        $this->middleware('permission:category_items_management', ['only' => 'DeleteImage']);
    }

    public function DeleteImage(ImageIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['imageId']);
        $image = $this->repository->ShowById(Image::class,$arr['imageId']);
        $path = \storage_path('app/public/'.$image->url);
        $count = $this->repository->ShowAll(Image::class,[
            'imageable_type' => $image->imageable_type,
            'imageable_id' => $image->imageable_id,
        ])->count();
        if($count > 1) {
            if (File::exists($path)) {
                File::delete($path);
            }
            $this->repository->DeleteById(Image::class, $arr['imageId']);
            return \Success('Image Deleted Successfully');
        }
        else{
            throw ValidationException::withMessages(['Last Image Dont Delete!']);
        }
    }

}
