<?php

namespace App\Http\Controllers\ItemExtra;

use App\Http\Controllers\Controller;
use App\Http\Requests\Color\AddColorRequest;
use App\Http\Requests\Color\ColorIdRequest;
use App\Http\Requests\Company\AddCompanyRequest;
use App\Http\Requests\Storage\AddStorageRequest;
use App\Http\Resources\Brand\BrandsResource;
use App\Http\Resources\Color\ColorsResource;
use App\Http\Resources\Storage\StoragessResource;
use App\Interfaces\Repository;
use App\Models\Brand;
use App\Models\Color;
use App\Models\ItemColor;
use App\Models\Storage;
use Database\Seeders\BrandSeeder;
use GrahamCampbell\ResultType\Success;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class ItemExtraController extends Controller
{
    public function __construct(public Repository $repository)
    {
    }

    public function CreateColor(AddColorRequest $request)
    {
        $arr = Arr::only($request->validated(), ['color']);
        $this->repository->Create(Color::class, $arr);
        return \Success('Color Add Successfully');
    }

    public function ShowAllColors()
    {
        $colors = $this->repository->ShowAll(Color::class, [])->get();
        $colors = ColorsResource::collection($colors);
        return \SuccessData('Colors Found Successfully', $colors);

    }

    public function CreateBrand(AddCompanyRequest $request)
    {
        $arr = Arr::only($request->validated(), ['name']);
        $this->repository->Create(Brand::class, $arr);
        return \Success('Brand Add Successfully');
    }

    public function ShowAllBrands()
    {
        $brands = $this->repository->ShowAll(Brand::class, [])->get();
        $brands = BrandsResource::collection($brands);
        return \SuccessData('Brands Found Successfully', $brands);

    }

    public function CreateStorage(AddStorageRequest $request)
    {
        $arr = Arr::only($request->validated(), ['size', 'unit']);
        $this->repository->Create(Storage::class, $arr);
        return \Success('Storage Add Successfully');
    }

    public function ShowAllStorages()
    {
        $storages = $this->repository->ShowAll(Storage::class, [])->get();
        $storages = StoragessResource::collection($storages);
        return \SuccessData('Storages Found Successfully', $storages);

    }

}
