<?php

namespace App\Http\Controllers\Order;

use App\Http\Controllers\Controller;
use App\Http\Requests\Order\AddOrderRequest;
use App\Http\Requests\Order\ChangeOrderStatusRequest;
use App\Http\Requests\Notification\NotificationRequest;
use App\Http\Requests\Order\GetOrdersRequest;
use App\Http\Requests\Order\OrderIdRequest;
use App\Http\Resources\Order\OrderItemsResource;
use App\Http\Resources\Order\ShowOrderResource;
use App\Interfaces\Repository;
use App\Models\Cart;
use App\Models\CartItem;
use App\Models\Currency;
use App\Models\Payment;
use App\Models\Order;
use App\Services\ChangeCurrencyService;
use Illuminate\Http\Request;
use App\Http\Controllers\Notification\NotificationController;
use Illuminate\Support\Arr;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class OrderController extends Controller
{
    public function __construct(public Repository $repository, public ChangeCurrencyService $service, public NotificationController $notificationController)
    {
        if (\request()->route()->getPrefix() == 'superAdmin_api') {
            $this->middleware('permission:orders_management', ['only' => ['GetOrderDetail', 'GetOrders', 'ChangeOrderStatus']]);
        }
    }

    public function Create(AddOrderRequest $request)
    {
        $customer_id = \auth('Customer')->user()->id;
        $arr = Arr::only($request->validated(), ['payment_id', 'name', 'phone', 'country_id', 'city_id', 'address', 'building_num']);
        if($arr['payment_id'] == 1){
            $arr['payment_id'] = null;
        }
        else{
            $arr['payment_id'] = $this->repository->ShowAll(Payment::class, ['name_en' => 'cash'])->first()->id;
        }
        $cartUser = $this->GetUserCart($customer_id);
        $currency = \returnCurrency();
        $arr['currency_id'] = $this->repository->ShowAll(Currency::class, ['name' => $currency])->first()->id;
        $orderPrice = 0;
        $orderCarts = $cartUser->CartItems;
        $arr['order_price'] = $this->GetOrderPrice($orderPrice, $orderCarts, $currency);
        $arr['cart_id'] = $cartUser->id;
        $order = $this->repository->Create(Order::class, $arr);
        $cartUser->update(['status' => 'pending']);
        return \SuccessData('Order Add Successfully', $order);
    }

    private function GetUserCart($customer_id)
    {
        $where = [
            'customer_id' => $customer_id,
            'status' => 'initial',
        ];
        $cartUser = $this->repository->ShowAll(Cart::class, $where)->first();
        if (!$cartUser) {
            throw new NotFoundHttpException('Dont Have Carts');
        }
        return $cartUser;
    }

    private function GetOrderPrice($orderPrice, $orderCarts, $currency)
    {

        foreach ($orderCarts as $cart) {
            $price = $cart->Item->ItemOffer()->Active()->first() ?
                $this->service->ChangePriceByCurrency($cart->Item->ItemOffer()->Active()->first()->offer_price, $cart->Item->Currency->name, $currency) :
                $this->service->ChangePriceByCurrency($cart->Item->price, $cart->Item->Currency->name, $currency);
            $cartPrice = $price * $cart->quantity;
            $orderPrice += $cartPrice;
            $this->repository->Update(CartItem::class, $cart->id, ['total_price' => $cartPrice]);
        }
        return $orderPrice;
    }


    public function GetOrders(GetOrdersRequest $request)
    {

        $perPage = \returnPerPage();
        $arr = Arr::only($request->validated(), ['customerId', 'status']);
        $where = [];
        if (\array_key_exists('status', $arr)) {
            $where = ['status' => $arr['status']];
        }
        $orders = $this->repository->ShowAll(Order::class, $where)->Order();
        if (\array_key_exists('customerId', $arr)) {
            $orders = $orders->CustomerOrders($arr['customerId']);
        }
        $orders = $orders->paginate($perPage);

        ShowOrderResource::collection($orders);
        return \Pagination($orders);
    }


    public function ChangeOrderStatus(ChangeOrderStatusRequest $request)
    {
        $arr = Arr::only($request->validated(), ['orderId', 'status']);
        $cart = $this->repository->ShowById(Order::class, $arr['orderId'])->Cart;
         $customer = $cart->Customer;
        
        $this->repository->Update(Order::class, $arr['orderId'], $arr);
        $this->repository->Update(Cart::class, $cart->id, ['status' => $arr['status']]);
         
       
         if ($arr['status'] == 'accepted') {

$notificationData = [
    'fcm_token' => $customer->fcm_token,
    'title' => 'order number ' . $arr['orderId'],
    'body' => 'The Order Accepted'
];

        } else {
              
        $notificationData = [
    'fcm_token' => $customer->fcm_token,
    'title' => 'order number ' . $arr['orderId'],
    'body' => 'The Order Rejected'
];
        }
       
    
       $this->sendNotification($notificationData);
        return \Success('Order Change Status Successfully');
    }

    public function GetOrderDetail(OrderIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['orderId']);
        $cart = $this->repository->ShowById(Order::class, $arr['orderId'])->Cart;
        $cartItems = $cart->CartItems;
        $cartItems = OrderItemsResource::collection($cartItems);
        return \SuccessData('Order Items Found Successfully', $cartItems);
    }

 private function sendNotification($arr)
    {
          
            $firebaseToken[0] = $arr['fcm_token'];
       
        $SERVER_API_KEY = 'AAAAdFHao_4:APA91bG0sDJmn1rQYJfXILJLvfIVTl92OQJbO4c0sMVDtZDE7v-uJ1gJDS77KEgTKIs_LtHUSui_9eMTIXChDB93rBvx_8zU3w-S9Qq7mONDKQCbccY9u9uiHlmu_psyhsTtmKySVuBO';

        $data = [
            "registration_ids" => $firebaseToken,
            "notification" => [
                "title" => $arr['title'],
                "body" => $arr['body'],
                "content_available" => true,
                "priority" => "high",
            ]
        ];
        $dataString = json_encode($data);

        $headers = [
            'Authorization: key=' . $SERVER_API_KEY,
            'Content-Type: application/json',
        ];

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);

        $response = curl_exec($ch);

        return \Success('Notification Send Successfully');
    }
}
