<?php

namespace App\Http\Controllers\Payment;

use App\Http\Controllers\Controller;
use App\Http\Requests\Payment\CreateMethodRequest;
use App\Http\Requests\Payment\MethodIdRequest;
use App\Http\Requests\Payment\UpdateMethodRequest;
use App\Http\Resources\Customer\PaymentMethodsResource;
use App\Interfaces\Repository;
use App\Models\Payment;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class PaymentController extends Controller
{

    public function __construct(public Repository $repository)
    {
    }

    public function Create(CreateMethodRequest $request)
    {
        $arr = Arr::only($request->validated(), ['name_ar', 'name_en', 'content']);
        $this->repository->Create(Payment::class, $arr);
        return \Success('Payment Method Created Successfully');
    }

    public function ShowAll()
    {
        $methods = $this->repository->ShowAll(Payment::class, [])->orderBy('name_en')->get();
        if (\request()->route()->getPrefix() == 'customer_api') {
            $methods = PaymentMethodsResource::collection($methods);
        }
        return \SuccessData('Payment Methods Found Successfully', $methods);
    }


    public function Update(UpdateMethodRequest $request)
    {
        $arr = Arr::only($request->validated(), ['methodId','content']);
            $this->repository->Update(Payment::class, $arr['methodId'], $arr);
        return \Success('Payment Method Updated Successfully');

    }

    public function Delete(MethodIdRequest $request){
    $arr = Arr::only($request->validated(),['methodId']);
    $this->repository->DeleteById(Payment::class,$arr['methodId']);
    return \Success('Payment Method Deleted Successfully');
    }
}
