<?php

namespace App\Http\Controllers\Setting;

use App\Http\Controllers\Controller;
use App\Http\Requests\Order\ChangeOrderStatusRequest;
use App\Http\Requests\Setting\AddSettingRequest;
use App\Http\Requests\Setting\ChangeMoneyPriceRequest;
use App\Http\Requests\Setting\EditValueSettingRequest;
use App\Http\Requests\Setting\SettingIdRequest;
use App\Http\Resources\Customer\SettingResource;
use App\Interfaces\Repository;
use App\Models\Currency;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class SettingController extends Controller
{


    public function __construct(public Repository $repository)
    {
        $this->middleware('permission:currency_management', ['only' => ['ChangeCurrenciesPrice']]);
        $this->middleware('permission:setting_management',['only'=>['Create','Update','Delete']]);
    }

    public function Create(AddSettingRequest $request)
    {
        $arr = Arr::only($request->validated(), ['parent','key_ar', 'value_ar', 'key_en', 'value_en']);
        $this->repository->Create(Setting::class, $arr);
        return \Success('Setting Add Successfully');
    }

    public function Update(EditValueSettingRequest $request)
    {
        $arr = Arr::only($request->validated(), ['settingId','value_ar','value_en']);
                $this->repository->Update(Setting::class, $arr['settingId'], $arr);
        return \Success('Setting Updated Successfully');
    }

    public function ShowAll()
    {
        $settings = $this->repository->ShowAll(Setting::class, [])->get();
        return \SuccessData('setting Found Successfully', $settings);
    }

    public function Delete(SettingIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['settingId']);
        $this->repository->DeleteById(Setting::class, $arr['settingId']);
        return \Success('Setting Delete Successfully');
    }

    public function ReturnAboutUs()
    {
        $setting = $this->repository->ShowAll(Setting::class, ['parent' => 'about us'])->get();
        $setting = SettingResource::collection($setting);
        return \SuccessData('About Us Found Successfully', $setting);
    }

    public function ReturnPrivacyPolicy()
    {
        $setting = $this->repository->ShowAll(Setting::class, ['parent' => 'privacy policy'])->get();
       $setting = SettingResource::collection($setting);
        return \SuccessData('Privacy Policy Found Successfully', $setting);
    }

    public function ChangeCurrenciesPrice(ChangeMoneyPriceRequest $request){
    $arr = Arr::only($request->validated(),['Dinar_price','Dollar_price']);
    $this->repository->ShowAll(Currency::class,['name' => 'Dinar'])->first()->update(['price' => $arr['Dinar_price']]);
    $this->repository->ShowAll(Currency::class,['name' => 'Dollar'])->first()->update(['price' => $arr['Dollar_price']]);
    return \Success('Currencies Update Price Successfully');
    }

}
