<?php

namespace App\Http\Controllers\SuperAdmin;

use App\Http\Controllers\Controller;
use App\Http\Requests\SuperAdmin\AddSuperAdminRequest;
use App\Http\Requests\SuperAdmin\LoginSuperAdminRequest;
use App\Http\Requests\SuperAdmin\SuperAdminIdRequest;
use App\Http\Requests\SuperAdmin\UpdateAdminPermissionsRequest;
use App\Http\Requests\SuperAdmin\ShowAdminsSearchRequest;
use App\Http\Resources\SuperAdmin\LoginSuperAdminResource;
use App\Interfaces\Repository;
use App\Models\SuperAdmin;
use GuzzleHttp\Promise\Create;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\ValidationException;
use Spatie\Permission\Models\Permission;

class SuperAdminController extends Controller
{

    public function __construct(public Repository $repository)
    {

        $this->middleware('permission:super_admin_management', ['only' => ['Create', 'ActiveOrNot', 'ShowPermissions', 'UpdateAdminPermissions', 'Delete','ShowAll']]);
    }

    public function Login(LoginSuperAdminRequest $request)
    {
        $arr = Arr::only($request->validated(), ['user_name', 'password']);
        $superAdmin = SuperAdmin::where('user_name', $arr['user_name'])->first();
        if (!Hash::check($arr['password'], $superAdmin->password)) {
            throw ValidationException::withMessages(['Password Not Correct']);
        }
        $token = $superAdmin->createToken('authToken', ['SuperAdmin'])->accessToken;
        $superAdmin['token'] = $token;
        return \SuccessData('Super Admin Login Successfully', new LoginSuperAdminResource($superAdmin));
    }

    public function Logout()
    {
        $superAdmin = \auth('SuperAdmin')->user();
        $superAdmin->tokens()->where('scopes', '["SuperAdmin"]')->delete();
        return \Success('Super Admin Logout Successfully');
    }

    public function Create(AddSuperAdminRequest $request)
    {
        $arr = Arr::only($request->validated(), ['name', 'user_name', 'password', 'permissions']);
        $superAdmin = $this->repository->Create(SuperAdmin::class, $arr);
        $permissionNames = Permission::whereIn('id', $arr['permissions'])->pluck('name')->toArray();
        $superAdmin->givePermissionTo($permissionNames);
        return \Success('Admin Add Successfully');
    }

    public function ActiveOrNot(SuperAdminIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['adminId']);
        $this->repository->ActiveOrNot(SuperAdmin::class, $arr['adminId']);
        return \Success('Super Admin Change Successfully');
    }

    public function ShowPermissions()
    {
        $permissions = $this->repository->ShowAll(Permission::class, [])->get(['id', 'name']);
        return \SuccessData('Permission Found Successfully', $permissions);
    }

    public function UpdateAdminPermissions(UpdateAdminPermissionsRequest $request)
    {
        $arr = Arr::only($request->validated(), ['adminId', 'permissions']);
        $admin = $this->repository->ShowById(SuperAdmin::class, $arr['adminId']);
        $permissionsName = Permission::whereIn('id', $arr['permissions'])->get();
        $admin->syncPermissions($permissionsName);
        return \Success('Admin Permissions Updated Successfully');
    }

    public function Delete(SuperAdminIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['adminId']);
        $this->repository->DeleteById(SuperAdmin::class, $arr['adminId']);
        return \Success('Admin Deleted Successfully');

    }
    
    public function ShowAll(ShowAdminsSearchRequest $request){
        $arr = Arr::only($request->validated(),['search']);
        $where = [];
        if(\array_key_exists('search',$arr)){
            $where = \array_merge($where,[['name','like','%'.$arr['search'].'%']]);
        }
    $admins = $this->repository->ShowAll(SuperAdmin::class,$where)->paginate(10);
    return \Pagination($admins);
    }
    
       public function ShowAdminPermissions(SuperAdminIdRequest $request)
    {
        $arr = Arr::only($request->validated(), ['adminId']);
        $admin = $this->repository->ShowById(SuperAdmin::class, $arr['adminId']);
        $permissions = $admin->permissions()->get(['id','name']);
        foreach($permissions as $permission){
        unset($permission->pivot);
        }
        return \SuccessData('Admin Permissions Found Successfully', $permissions);
    }
}
