<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Card extends Model
{
    use HasFactory, SoftDeletes;

    protected $primaryKey = 'id';

    protected $fillable = [
        'card_sub_id',
        'name_ar',
        'name_en',
        'description_ar',
        'description_en',
        'image',
        'price',
        'currency_id',
        'quantity',
        'is_active',
    ];

    protected $hidden = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

protected $casts =[
    'quantity' => 'integer',
];

    public function scopeActive($query){
        return $query->where('is_active',1);
    }

    public function CardSubCategory(): BelongsTo
    {
        return $this->belongsTo(CardSubCategory::class, 'card_sub_id')->withTrashed();
    }

    public function Currency(): BelongsTo
    {
        return $this->belongsTo(Currency::class, 'currency_id');
    }

    /** @noinspection PhpUnused */
    public function CardCodes(): HasMany
    {
        return $this->hasMany(CardCode::class, 'card_id');
    }


    public function CardOrders(): HasMany
    {
        return $this->hasMany(CardOrder::class, 'card_id');
    }

}
