<?php

namespace App\Models;

use App\Http\Controllers\CardSubCategory\CardSubCategoryController;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class CardCategory extends Model
{
    use HasFactory, SoftDeletes;

    protected $primaryKey = 'id';

    protected $fillable = [
        'superAdmin_id',
        'name_ar',
        'name_en',
        'image',
        'is_active',
    ];

    protected $hidden = [
        'superAdmin_id',
        'created_at',
        'updated_at',
    ];

    protected static function boot()
    {
        parent::boot(); // TODO: Change the autogenerated stub

        static::creating(function ($model) {
            $model->setSuperAttribute();
        });

    }

    public function scopeActive($query)
    {
        return $query->where('is_active', 1);
    }

    public function setSuperAttribute()
    {
        $this->attributes['superAdmin_id'] = \auth('SuperAdmin')->user()->id;
    }

    public function SuperAdmin(): BelongsTo
    {
        return $this->belongsTo(SuperAdmin::class, 'superAdmin_id');
    }


    public function CardSubCategories(): HasMany
    {
        return $this->hasMany(CardSubCategory::class, 'card_category_id');
    }
}
