<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Currency extends Model
{
    use HasFactory;

    protected $primaryKey = 'id';

    protected $fillable = [
        'superAdmin_id',
        'name',
        'symbol',
        'price',
    ];

    protected $hidden = [
        'superAdmin_id',
        'created_at',
        'updated_at',
    ];

    protected static function boot()
    {
        parent::boot(); // TODO: Change the autogenerated stub

        static::creating(function ($model) {
            $model->setSuperAttribute();
        });

    }

    public function setSuperAttribute()
    {
        $this->attributes['superAdmin_id'] = \auth('SuperAdmin')->user()->id;
    }

    public function SuperAdmin(): BelongsTo
    {
        return $this->belongsTo(SuperAdmin::class, 'superAdmin_id');
    }

    public function Items(): HasMany
    {
        return $this->hasMany(Item::class, 'currency_id');
    }

    public function Orders(): HasMany
    {
        return $this->hasMany(Order::class, 'currency_id');
    }

    public function Cards(): HasMany
    {
        return $this->hasMany(Card::class, 'currency_id');
    }

    public function CardOrders(): HasMany
    {
        return $this->hasMany(CardOrder::class, 'currency_id');
    }
}
