<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;

use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Hash;
use Laravel\Passport\HasApiTokens;
use Illuminate\Foundation\Auth\User as Authenticatable;

class Customer extends Authenticatable
{
    use HasFactory, HasApiTokens, SoftDeletes;

    protected $primaryKey = 'id';

    protected $fillable = [
        'user_name',
        'email',
        'password',
        'phone',
        'fcm_token',
        'balance',
        'is_trader',
        'is_active',
    ];

    protected $hidden = [
        'password',
        'created_at',
        'updated_at',
    ];

    public function setPasswordAttribute($value)
    {
        $this->attributes['password'] = Hash::make($value);
    }

    public function Carts(): HasMany
    {
        return $this->hasMany(Cart::class, 'customer_id');
    }

    public function Favorites(): HasMany
    {
        return $this->hasMany(Favorite::class, 'customer_id');
    }

    public function CardOrders(): HasMany
    {
        return $this->hasMany(CardOrder::class, 'customer_id');
    }
}
