<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Item extends Model
{
    use HasFactory,SoftDeletes;

    protected $primaryKey = 'id';

    protected $fillable = [
        'category_id',
        'brand_id',
        'currency_id',
        'storage_id',
        'name_ar',
        'name_en',
        'description_ar',
        'description_en',
        'price',
        'is_special',
        'is_active',
    ];

    protected $hidden = [
        'created_at',
        'updated_at',
    ];

    public function scopeActive($query)
    {
        return $query->where('is_active', 1);
    }

    public function Category(): BelongsTo
    {
        return $this->belongsTo(Category::class, 'category_id')->withTrashed();
    }

    public function Brand(): BelongsTo
    {
        return $this->belongsTo(Brand::class, 'brand_id');
    }

    /** @noinspection PhpUnused */
    public function Currency(): BelongsTo
    {
        return $this->belongsTo(Currency::class, 'currency_id');
    }

    public function Images(): MorphMany
    {
        return $this->morphMany(Image::class, 'imageable');
    }

    public function ItemColors(): HasMany
    {
        return $this->hasMany(ItemColor::class, 'item_id');
    }

    public function ItemOffer(): HasOne
    {
        return $this->hasOne(ItemOffer::class, 'item_id');
    }

    public function Storage(): BelongsTo
    {
        return $this->belongsTo(Storage::class, 'storage_id');
    }

    public function Favorites(): HasMany
    {
        return $this->hasMany(Favorite::class, 'item_id');
    }

    public function CartItems(): HasMany
    {
        return $this->hasMany(CartItem::class, 'item_id');
    }
}
