<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Order extends Model
{
    use HasFactory;

    protected $primaryKey = 'id';

    protected $fillable = [
        'cart_id',
        'order_price',
        'currency_id',
        'payment_id',
        'name',
        'phone',
        'country_id',
        'city_id',
        'address',
        'building_num',
        'status',
    ];

    protected $hidden = [
        'created_at',
        'updated_at',
    ];

    public function scopeOrder($query)
    {
        return $query->orderBy('created_at', 'desc');
    }

    public function scopeCustomerOrders($query, $customerId)
    {
        return $query->whereHas('Cart', function ($q) use ($customerId) {
            $q->where('customer_id', $customerId);
        });
    }

    public function Cart(): BelongsTo
    {
        return $this->belongsTo(Cart::class, 'cart_id');
    }

    public function Currency(): BelongsTo
    {
        return $this->belongsTo(Currency::class, 'currency_id');
    }

    public function Payment(): BelongsTo
    {
        return $this->belongsTo(Payment::class, 'payment_id')->withTrashed();
    }

    public function Country(): BelongsTo
    {
        return $this->belongsTo(Country::class, 'country_id');
    }

    public function City(): BelongsTo
    {
        return $this->belongsTo(City::class, 'city_id');
    }
}
