<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Hash;
use Laravel\Passport\HasApiTokens;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Spatie\Permission\Traits\HasPermissions;
use Spatie\Permission\Traits\HasRoles;

class SuperAdmin extends Authenticatable
{
    use HasFactory, HasApiTokens, HasPermissions,HasRoles,SoftDeletes;

    protected $primaryKey = 'id';

    protected $fillable = [
        'name',
        'user_name',
        'password',
        'is_active',
    ];

    protected $hidden = [
        'password',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

protected $casts = [
    'is_active' => 'integer',
];

    public function setPasswordAttribute($value)
    {
        $this->attributes['password'] = Hash::make($value);
    }

    public function Apps(): HasMany
    {
        return $this->hasMany(App::class, 'superAdmin_id');
    }

    public function Links(): HasMany
    {
        return $this->hasMany(Link::class, 'superAdmin_id');
    }

    public function Notifications(): HasMany
    {
        return $this->hasMany(Notification::class, 'superAdmin_id');
    }

    public function Colors(): HasMany
    {
        return $this->hasMany(Color::class, 'superAdmin_id');
    }

    /** @noinspection PhpUnused */
    public function Categories(): HasMany
    {
        return $this->hasMany(Category::class, 'superAdmin_id');
    }

    /** @noinspection PhpUnused */
    public function CardCategories(): HasMany
    {
        return $this->hasMany(CardCategory::class, 'superAdmin_id');
    }

    public function Brands(): HasMany
    {
        return $this->hasMany(Brand::class, 'superAdmin_id');
    }

    public function Currencies(): HasMany
    {
        return $this->hasMany(Currency::class, 'superAdmin_id');
    }

    public function Storages(): HasMany
    {
        return $this->hasMany(Storage::class, 'superAdmin_id');
    }

    public function Payments(): HasMany
    {
        return $this->hasMany(Payment::class, 'superAdmin_id');
    }

    public function Settings(): HasMany
    {
        return $this->hasMany(Setting::class, 'superAdmin_id');
    }
}
