<?php

use App\Http\Controllers\Card\CardController;
use App\Http\Controllers\CardCategory\CardCategoryController;
use App\Http\Controllers\CardOrder\CardOrderController;
use App\Http\Controllers\Cart\CartController;
use App\Http\Controllers\Category\CategoryController;
use App\Http\Controllers\Communication\CommunicationController;
use App\Http\Controllers\Customer\CustomerController;
use App\Http\Controllers\Item\ItemController;
use App\Http\Controllers\ItemOffer\ItemOfferController;
use App\Http\Controllers\Location\LocationController;
use App\Http\Controllers\Order\OrderController;
use App\Http\Controllers\Payment\PaymentController;
use App\Http\Controllers\Setting\SettingController;
use App\Http\Controllers\CardSubCategory\CardSubCategoryController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/



Route::post('/send_email_code',[CustomerController::class,'EmailVerificationCode']);
Route::post('/send_password_code',[CustomerController::class,'ResetPasswordCode']);
Route::post('/add_customer',[CustomerController::class,'Create']);
Route::post('/login',[CustomerController::class,'Login']);
Route::post('/reset_password',[CustomerController::class,'ResetPassword']);

Route::group(['middleware' => ['auth:Customer', 'scope:Customer','access']], function () {
Route::post('/logout',[CustomerController::class,'Logout']);
    Route::get('/show_categories',[CategoryController::class,'ShowAll']);
    Route::get('/show_one_item',[ItemController::class,'ShowById'])->middleware('currency');
    Route::get('/show_items',[ItemController::class,'ShowAll'])->middleware('currency');
    Route::get('/show_offers',[ItemOfferController::class,'ShowAll'])->middleware('currency');
    Route::get('/show_card_categories',[CardCategoryController::class,'ShowAll']);
    Route::get('/show_one_card_categories',[CardCategoryController::class,'ShowById']);
Route::post('/change_order_status', [OrderController::class, 'ChangeOrderStatus']);
    Route::get('/show_one_card',[CardController::class,'ShowById']);
    Route::get('/show_cards',[CardController::class,'ShowAll']);
    Route::post('/add_to_cart',[CartController::class,'AddToCart']);
    Route::get('/show_cart',[CartController::class,'ShowCart'])->middleware('currency');
    Route::post('/update_cart',[CartController::class,'EditCart']);
    Route::delete('/delete_cart',[CartController::class,'DeleteCart']);
    Route::delete('/delete_all_cart_items',[CartController::class,'DeleteAllCartItems']);
    Route::post('/add_order',[OrderController::class,'Create']);
    Route::get('/show_orders',[OrderController::class,'GetOrders']);
    Route::get('/show_order_detail',[OrderController::class,'GetOrderDetail']);
    Route::post('/like_or_not_item',[ItemController::class,'LikeOrNot']);
    Route::get('/show_favorites',[ItemController::class,'ShowFavoriteItems']);

    Route::get('/show_about_us',[SettingController::class,'ReturnAboutUs']);
    Route::get('/show_privacy_policy',[SettingController::class,'ReturnPrivacyPolicy']);
    Route::get('/show_payment_methods',[PaymentController::class,'ShowAll']);
    Route::get('/show_links',[CommunicationController::class,'ShowAllLinks']);

    Route::get('/show_countries',[LocationController::class,'ShowAllCountries']);
    Route::get('/show_cities_by_country',[LocationController::class,'ShowCitiesByCountry']);

    Route::post('/add_card_order',[CardOrderController::class,'Create']);

    Route::controller(CardSubCategoryController::class)->group(function (){
        Route::get('/show_card_sub_categories','ShowAll');
    });

    Route::get('/show_balance',[CustomerController::class,'ShowBalance']);
});

