<?php

use App\Http\Controllers\Card\CardController;
use App\Http\Controllers\CardCategory\CardCategoryController;
use App\Http\Controllers\CardOrder\CardOrderController;
use App\Http\Controllers\CardSubCategory\CardSubCategoryController;
use App\Http\Controllers\Category\CategoryController;
use App\Http\Controllers\ItemExtra\ItemExtraController;
use App\Http\Controllers\Communication\CommunicationController;
use App\Http\Controllers\Customer\CustomerController;
use App\Http\Controllers\Image\ImageController;
use App\Http\Controllers\Item\ItemController;
use App\Http\Controllers\ItemOffer\ItemOfferController;
use App\Http\Controllers\Notification\NotificationController;
use App\Http\Controllers\Order\OrderController;
use App\Http\Controllers\Payment\PaymentController;
use App\Http\Controllers\Setting\SettingController;
use App\Http\Controllers\SuperAdmin\SuperAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/

Route::post('/login', [SuperAdminController::class, 'Login']);

Route::group(['middleware' => ['auth:SuperAdmin', 'scope:SuperAdmin','access']], function () {

    Route::post('/add_category', [CategoryController::class, 'Create']);
    Route::post('/active_or_not_category', [CategoryController::class, 'ActiveOrNot']);
    Route::get('/show_one_category', [CategoryController::class, 'ShowById']);
    Route::get('/show_categories', [CategoryController::class, 'ShowAll']);

    Route::post('/add_item', [ItemController::class, 'Create']);
    Route::post('/active_or_not_item', [ItemController::class, 'ActiveOrNot']);
    Route::post('/special_or_not_item', [ItemController::class, 'SpecialOrNot']);
    Route::get('/show_one_item', [ItemController::class, 'ShowById']);
    Route::get('/show_items', [ItemController::class, 'ShowAll']);

    Route::post('/add_offer', [ItemOfferController::class, 'Create']);
    Route::get('/show_offers', [ItemOfferController::class, 'ShowAll']);

    Route::delete('/delete_offer', [ItemOfferController::class, 'DeleteById']);

    Route::post('/add_setting', [SettingController::class, 'Create']);
    Route::post('/add_admin', [SuperAdminController::class, 'Create']);
    Route::get('/show_admins', [SuperAdminController::class, 'ShowAll']);
    Route::get('/show_admin_permissions', [SuperAdminController::class, 'ShowAdminPermissions']);

    Route::post('/active_or_not_admin', [SuperAdminController::class, 'ActiveOrNot']);
    Route::post('/change_order_status', [OrderController::class, 'ChangeOrderStatus']);
    Route::get('/show_orders', [OrderController::class, 'GetOrders']);
    Route::get('/show_order_detail', [OrderController::class, 'GetOrderDetail']);
    Route::post('/update_category', [CategoryController::class, 'Update']);
    Route::delete('/delete_image', [ImageController::class, 'DeleteImage']);
    Route::delete('/delete_item_color', [ItemController::class, 'DeleteItemColor']);
    Route::post('/update_item', [ItemController::class, 'Update']);
    Route::get('/show_customers', [CustomerController::class, 'ShowAll']);
    Route::post('/active_or_not_customer', [CustomerController::class, 'ActiveOrNot']);
    Route::post('/trader_or_not_customer', [CustomerController::class, 'TraderOrNot']);
    Route::post('/recharge_money', [CustomerController::class, 'RechargeMoney']);

    Route::get('/show_permissions', [SuperAdminController::class, 'ShowPermissions']);

    Route::post('/update_admin_permissions', [SuperAdminController::class, 'UpdateAdminPermissions']);
    Route::get('/show_settings', [SettingController::class, 'ShowAll']);
    Route::post('/update_settings', [SettingController::class, 'Update']);
    Route::delete('/delete_setting', [SettingController::class, 'Delete']);

    Route::post('/add_payment_method', [PaymentController::class, 'Create']);
    Route::get('/show_payment_methods', [PaymentController::class, 'ShowAll']);
    Route::post('/update_payment_methods', [PaymentController::class, 'Update']);
    Route::delete('/delete_payment_method', [PaymentController::class, 'Delete']);

    Route::post('/update_currencies_price', [SettingController::class, 'ChangeCurrenciesPrice']);
    Route::post('/logout', [SuperAdminController::class, 'Logout']);

    Route::post('/add_app', [CommunicationController::class, 'CreateApp']);
    Route::delete('/delete_app', [CommunicationController::class, 'DeleteApp']);
    Route::get('/show_apps', [CommunicationController::class, 'ShowAllApps']);

    Route::post('/add_link', [CommunicationController::class, 'CreateLink']);
    Route::post('/update_links', [CommunicationController::class, 'UpdateLinks']);
    Route::post('/update_app', [CommunicationController::class, 'UpdateApp']);
    Route::delete('/delete_link', [CommunicationController::class, 'DeleteLink']);
    Route::get('/show_links', [CommunicationController::class, 'ShowAllLinks']);

    Route::delete('/delete_category', [CategoryController::class, 'Delete']);

    Route::delete('delete_admin', [SuperAdminController::class, 'Delete']);
    Route::delete('delete_customer', [CustomerController::class, 'Delete']);

    Route::post('/add_color', [ItemExtraController::class, 'CreateColor']);
    Route::post('/add_brand', [ItemExtraController::class, 'CreateBrand']);
    Route::post('/add_storage', [ItemExtraController::class, 'CreateStorage']);
    Route::get('/show_colors', [ItemExtraController::class, 'ShowAllColors']);
    Route::get('/show_storages', [ItemExtraController::class, 'ShowAllStorages']);
    Route::get('/show_brands', [ItemExtraController::class, 'ShowAllBrands']);

    Route::delete('/delete_item', [ItemController::class, 'Delete']);
    Route::post('/send_notification',[NotificationController::class,'sendNotification']);


    Route::post('/add_card_category',[CardCategoryController::class,'Create']);
    Route::post('/active_or_not_card_category',[CardCategoryController::class,'ActiveOrNot']);
    Route::post('/update_card_category',[CardCategoryController::class,'Update']);
    Route::get('/show_card_categories',[CardCategoryController::class,'ShowAll']);
    Route::get('/show_one_card_categories',[CardCategoryController::class,'ShowById']);
    Route::delete('/delete_card_category', [CardCategoryController::class, 'Delete']);

    Route::post('/add_card',[CardController::class,'Create']);
    Route::post('/active_or_not_card',[CardController::class,'ActiveOrNot']);
    Route::delete('/delete_card', [CardController::class, 'Delete']);
    Route::post('/add_card_code',[CardController::class,'AddCardCode']);
    Route::delete('/delete_card_code', [CardController::class, 'DeleteCardCode']);
    Route::post('/add_card_quantity',[CardController::class,'AddCardQuantity']);
    Route::delete('/delete_card_quantity', [CardController::class, 'DeleteCardQuantity']);

    Route::get('/show_one_card',[CardController::class,'ShowById']);
    Route::get('/show_cards',[CardController::class,'ShowAll']);
    Route::post('/update_card',[CardController::class,'Update']);

    Route::post('/change_card_order_status',[CardOrderController::class,'ChangeCardOrderStatus']);
    Route::get('/show_card_orders',[CardOrderController::class,'ShowAll']);

    Route::controller(CardSubCategoryController::class)->group(function (){
        Route::post('/add_card_sub_category','Create');
        Route::post('/active_or_not_card_sub_category','ActiveOrNot');
        Route::get('/show_one_card_sub_category','ShowById');
        Route::get('/show_card_sub_categories','ShowAll');
        Route::post('/update_card_sub_category','Update');
        Route::delete('/delete_card_sub_category','Delete');
    });

});
